@@ -5,7 +5,6 @@ use warnings;
 use 5.008_001;
 
 use Carp;
-use Encode::Guess qw(euc-jp shiftjis 7bit-jis);
 use File::Basename 'basename';
 use Getopt::Long qw(:config posix_default no_ignore_case no_ignore_case_always);
 use IO::Socket::INET;
@@ -14,18 +13,19 @@ use Term::ReadLine;
 
 use App::Memcached::CLI;
 use App::Memcached::CLI::DataSource;
+use App::Memcached::CLI::Item;
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.2.2';
+use version; our $VERSION = 'v0.2.3';
 
 my %COMMAND2ALIASES = (
     help      => ['\h'],
     quit      => [qw(\q exit)],
-    get       => [],
     display   => [qw(\d)],
     stats     => [qw(\s)],
     settings  => [qw(\c config)],
     cachedump => [qw(\cd dump)],
+    get       => [],
 );
 my %COMMAND_OF;
 while (my ($cmd, $aliases) = each %COMMAND2ALIASES) {
@@ -34,7 +34,6 @@ while (my ($cmd, $aliases) = each %COMMAND2ALIASES) {
 }
 
 my $DEFAULT_CACHEDUMP_SIZE = 20;
-my $SHOW_DATA_LENGTH       = 320;
 
 sub new {
     my $class  = shift;
@@ -140,14 +139,6 @@ sub help {
             command => 'quit',
             summary => 'Exit',
         },
-        +{
-            command => 'get',
-            summary => 'Get data of KEY',
-            description => <<'EODESC',
-Usage:
-    > get <KEY>
-EODESC
-        },
         +{
             command => 'display',
             summary => 'Display slabs info',
@@ -168,6 +159,14 @@ Usage:
     > cachedump <CLASS> <NUMBER>
     > cachedump 1 10
     > cachedump 3     # default <NUMBER>
+EODESC
+        },
+        +{
+            command => 'get',
+            summary => 'Get data of KEY',
+            description => <<'EODESC',
+Usage:
+    > get <KEY>
 EODESC
         },
     );
@@ -217,24 +216,10 @@ sub _sorted_aliases_of {
 sub get {
     my $self = shift;
     my $key  = shift;
-    my $data = $self->{ds}->get($key);
-
-    my $value = $data->{value};
-    my $string = Encode::decode('Guess', $data->{value});
-    unless ($string) {
-        debug "Decode Guess failed for key - $key";
-        $value = '(binary)';
-    } elsif ((my $length = length $string) > $SHOW_DATA_LENGTH) {
-        $value = substr($string, 0, $SHOW_DATA_LENGTH - 1);
-        $value .= '...(the rest is skipped)';
-    }
-    $data->{value} = $value;
-
-    my $space = q{ } x 4;
-    for my $key (qw/key value flags length/) {
-        printf "%s%6s:%s%s\n", $space, $key, $space, $data->{$key};
-    }
+    my $item = App::Memcached::CLI::Item->find_by_get($key, $self->{ds});
+    return unless $item;
 
+    print $item->output;
     return 1;
 }
 
